Type Alias N64

pub type N64 = NoisyFloat<f64, NumChecker>;
A floating point number behaving like f64 that does not allow NaN.

The “N” in the name stands for “Number”, since all values of this type are “numbers”, i.e. they are not “not-a-number”.

Aliased Type

struct N64 { /* private fields */ }

Implementations

Source

impl N64

pub const fn unchecked_new(value: f64) -> Self

A const constructor that does not check whether value is valid.

WARNING: This constructor does not panic even in debug mode. As always, it is the user’s responsibility to ensure value is valid. Until Rust supports panics in const functions, this constructor is necessary to create a NoisyFloat in a const setting.

pub const fn const_raw(self) -> f64

A const function that returns the underlying float value.