Type Alias R32

pub type R32 = NoisyFloat<f32, FiniteChecker>;
A floating point number behaving like f32 that does not allow NaN or +/- Infinity.

The “R” in the name stands for “Real”, since in Mathematics, the Real numbers do not include NaN or +/- Infinity.

Aliased Type

struct R32 { /* private fields */ }

Implementations

Source

impl R32

pub const fn unchecked_new(value: f32) -> Self

A const constructor that does not check whether value is valid.

WARNING: This constructor does not panic even in debug mode. As always, it is the user’s responsibility to ensure value is valid. Until Rust supports panics in const functions, this constructor is necessary to create a NoisyFloat in a const setting.

pub const fn const_raw(self) -> f32

A const function that returns the underlying float value.