pub type N64 = NoisyFloat<f64, NumChecker>;Expand description
A floating point number behaving like f64 that does not allow NaN.
The “N” in the name stands for “Number”, since all values of this type are “numbers”, i.e. they are not “not-a-number”.
Aliased Type
struct N64 { /* private fields */ }Implementations
Sourceimpl N64
impl N64
Sourcepub const fn unchecked_new(value: f64) -> Self
pub const fn unchecked_new(value: f64) -> Self
A const constructor that does not check whether value is valid.
WARNING: This constructor does not panic even in debug mode.
As always, it is the user’s responsibility to ensure value is valid.
Until Rust supports panics in const functions, this constructor
is necessary to create a NoisyFloat in a const setting.