pub type R32 = NoisyFloat<f32, FiniteChecker>;Expand description
A floating point number behaving like f32 that does not allow NaN or +/- Infinity.
The “R” in the name stands for “Real”, since in Mathematics, the Real numbers do not include NaN or +/- Infinity.
Aliased Type
struct R32 { /* private fields */ }Implementations
Sourceimpl R32
impl R32
Sourcepub const fn unchecked_new(value: f32) -> Self
pub const fn unchecked_new(value: f32) -> Self
A const constructor that does not check whether value is valid.
WARNING: This constructor does not panic even in debug mode.
As always, it is the user’s responsibility to ensure value is valid.
Until Rust supports panics in const functions, this constructor
is necessary to create a NoisyFloat in a const setting.